@@ -1,6 +1,4 @@
-"""
-SatNOGS Config module main function
-"""
+"""SatNOGS Config module main function"""
 import sys
 
 import satnogsconfig
