@@ -294,8 +294,8 @@ class Menu():
         if not options.get('title'):
             options['title'] = menu['short_description']
         default_value = options.get('init')
-        if init_value := self._config.get_variable(
-            menu['variable']
+        if (
+            init_value := self._config.get_variable(menu['variable'])
         ) is not None:
             options['init'] = str(init_value)
         if options.get('init') is None:
@@ -324,8 +324,8 @@ class Menu():
         if not options.get('title'):
             options['title'] = menu['short_description']
         default_value = not (options.get('defaultno') or False)
-        if init_value := self._config.get_variable(
-            menu['variable']
+        if (
+            init_value := self._config.get_variable(menu['variable'])
         ) is not None:
             options['defaultno'] = not init_value
 
