@@ -1,6 +1,4 @@
-"""
-Settings module
-"""
+"""Settings module"""
 import os
 from pathlib import Path
 
